==> tickr_0.6.0.orig.tar.gz: tickr_0.6.0.orig/src/libetm-0.4.3/win32_specific.h <==
/*
 *	libetm-0.4 / win32_specific.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
 *	<manutm007@gmail.com>
 *
 *	- win32 specific functions -
 *
 * 	This program is free software: you can redistribute it and/or modify
 * 	it under the terms of the GNU General Public License as published by
 * 	the Free Software Foundation, either version 3 of the License, or
 * 	(at your option) any later version.
 *
 * 	This program is distributed in the hope that it will be useful,
 * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * 	GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License
 * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef INC_LIBETM_WIN32_SPECIFIC_H
#define INC_LIBETM_WIN32_SPECIFIC_H

#ifdef G_OS_WIN32
# ifndef WIN32_V
#  define WIN32_V
# endif
#endif

#ifdef WIN32_V
/* return NULL if error */
const char	*get_appdata_dir();
const char	*get_progfiles_dir();
/* key_value must be able to store 255 chars */
int		get_key_value_from_win32registry(const char *, char *);
int		save_key_value_into_win32registry(const char *, const char *);
/* return NULL if error */
const char	*get_default_browser_from_win32registry();
/* return -1 if error */
int		get_win32_taskbar_height();
/* find up to 15 mac addresses for this computer
 * return NULL if error */
/*const char 	**find_mac_addresses();*/
#endif
#endif /* INC_LIBETM_WIN32_SPECIFIC_H */

==> tickr_0.6.1.orig.tar.gz: tickr_0.6.1.orig/src/libetm-0.4.3/win32_specific.h <==
/*
 *	libetm-0.4 / win32_specific.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
 *	<manutm007@gmail.com>
 *
 *	- Win32 specific functions -
 *
 * 	This program is free software: you can redistribute it and/or modify
 * 	it under the terms of the GNU General Public License as published by
 * 	the Free Software Foundation, either version 3 of the License, or
 * 	(at your option) any later version.
 *
 * 	This program is distributed in the hope that it will be useful,
 * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * 	GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License
 * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef INC_LIBETM_WIN32_SPECIFIC_H
#define INC_LIBETM_WIN32_SPECIFIC_H

#ifdef G_OS_WIN32
# ifndef WIN32_V
#  define WIN32_V
# endif
#endif

#ifdef WIN32_V
/* Return NULL if error */
const char	*get_appdata_dir();
const char	*get_progfiles_dir();
/* key_value must be able to store 255 chars */
int		get_key_value_from_win32registry(const char *, char *);
int		save_key_value_into_win32registry(const char *, const char *);
/* Return NULL if error */
const char	*get_default_browser_from_win32registry();
/* Return -1 if error */
int		get_win32_taskbar_height();
/* Find up to 15 mac addresses for this computer
 * Return NULL if error */
/*const char 	**find_mac_addresses();*/
#endif
#endif /* INC_LIBETM_WIN32_SPECIFIC_H */
